Process `input` texture and generate a bloom overlay on top of `output`, input and output must be of the same size.

Use [CreateBloomFromFile]/[CreateBloomFromAssets] to create a [Bloom] object and [DestroyBloom] to destroy its internal resources after usage.